package Acme::MilkyHolmes::Character::NeroYuzurizaki;
use Mouse;
extends 'Acme::MilkyHolmes::Group::MilkyHolmes';

use utf8;

no Mouse;

1;

__DATA__
@@ common
color: yellow

@@ en
---
firstname: Nero
familyname: Yuzurizaki
birthday: August 28
voiced_by: Sora Tokui
toys: Direct Hack

@@ ja
---
firstname: ネロ
familyname: 譲崎
birthday: 8/28
voiced_by: 徳井 青空
toys: ダイレクトハック
