package Acme::MilkyHolmes::Character::KazumiTokiwa;
use Mouse;
extends 'Acme::MilkyHolmes::Group::MilkyHolmes';

use utf8;

no Mouse;

1;

__DATA__

@@ common
---
color: black
color_enable: 0

@@ en
---
firstname: Kazumi
familyname: Tokiwa
birthday:
voiced_by: Aimi
toys: Arrow

@@ ja
---
firstname: カズミ
familyname: 常盤
birthday:
voiced_by: 愛美
toys: アロー
